#line 2 "sieve/sieve-lex.c"

#line 4 "sieve/sieve-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer sieve_create_buffer
#define yy_delete_buffer sieve_delete_buffer
#define yy_scan_buffer sieve_scan_buffer
#define yy_scan_string sieve_scan_string
#define yy_scan_bytes sieve_scan_bytes
#define yy_init_buffer sieve_init_buffer
#define yy_flush_buffer sieve_flush_buffer
#define yy_load_buffer_state sieve_load_buffer_state
#define yy_switch_to_buffer sieve_switch_to_buffer
#define yypush_buffer_state sievepush_buffer_state
#define yypop_buffer_state sievepop_buffer_state
#define yyensure_buffer_stack sieveensure_buffer_stack
#define yy_flex_debug sieve_flex_debug
#define yyin sievein
#define yyleng sieveleng
#define yylex sievelex
#define yylineno sievelineno
#define yyout sieveout
#define yyrestart sieverestart
#define yytext sievetext
#define yywrap sievewrap
#define yyalloc sievealloc
#define yyrealloc sieverealloc
#define yyfree sievefree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define sieve_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer sieve_create_buffer
#endif

#ifdef yy_delete_buffer
#define sieve_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer sieve_delete_buffer
#endif

#ifdef yy_scan_buffer
#define sieve_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer sieve_scan_buffer
#endif

#ifdef yy_scan_string
#define sieve_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string sieve_scan_string
#endif

#ifdef yy_scan_bytes
#define sieve_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes sieve_scan_bytes
#endif

#ifdef yy_init_buffer
#define sieve_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer sieve_init_buffer
#endif

#ifdef yy_flush_buffer
#define sieve_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer sieve_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define sieve_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state sieve_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define sieve_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer sieve_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define sievepush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state sievepush_buffer_state
#endif

#ifdef yypop_buffer_state
#define sievepop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state sievepop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define sieveensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack sieveensure_buffer_stack
#endif

#ifdef yylex
#define sievelex_ALREADY_DEFINED
#else
#define yylex sievelex
#endif

#ifdef yyrestart
#define sieverestart_ALREADY_DEFINED
#else
#define yyrestart sieverestart
#endif

#ifdef yylex_init
#define sievelex_init_ALREADY_DEFINED
#else
#define yylex_init sievelex_init
#endif

#ifdef yylex_init_extra
#define sievelex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra sievelex_init_extra
#endif

#ifdef yylex_destroy
#define sievelex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy sievelex_destroy
#endif

#ifdef yyget_debug
#define sieveget_debug_ALREADY_DEFINED
#else
#define yyget_debug sieveget_debug
#endif

#ifdef yyset_debug
#define sieveset_debug_ALREADY_DEFINED
#else
#define yyset_debug sieveset_debug
#endif

#ifdef yyget_extra
#define sieveget_extra_ALREADY_DEFINED
#else
#define yyget_extra sieveget_extra
#endif

#ifdef yyset_extra
#define sieveset_extra_ALREADY_DEFINED
#else
#define yyset_extra sieveset_extra
#endif

#ifdef yyget_in
#define sieveget_in_ALREADY_DEFINED
#else
#define yyget_in sieveget_in
#endif

#ifdef yyset_in
#define sieveset_in_ALREADY_DEFINED
#else
#define yyset_in sieveset_in
#endif

#ifdef yyget_out
#define sieveget_out_ALREADY_DEFINED
#else
#define yyget_out sieveget_out
#endif

#ifdef yyset_out
#define sieveset_out_ALREADY_DEFINED
#else
#define yyset_out sieveset_out
#endif

#ifdef yyget_leng
#define sieveget_leng_ALREADY_DEFINED
#else
#define yyget_leng sieveget_leng
#endif

#ifdef yyget_text
#define sieveget_text_ALREADY_DEFINED
#else
#define yyget_text sieveget_text
#endif

#ifdef yyget_lineno
#define sieveget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno sieveget_lineno
#endif

#ifdef yyset_lineno
#define sieveset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno sieveset_lineno
#endif

#ifdef yywrap
#define sievewrap_ALREADY_DEFINED
#else
#define yywrap sievewrap
#endif

#ifdef yyalloc
#define sievealloc_ALREADY_DEFINED
#else
#define yyalloc sievealloc
#endif

#ifdef yyrealloc
#define sieverealloc_ALREADY_DEFINED
#else
#define yyrealloc sieverealloc
#endif

#ifdef yyfree
#define sievefree_ALREADY_DEFINED
#else
#define yyfree sievefree
#endif

#ifdef yytext
#define sievetext_ALREADY_DEFINED
#else
#define yytext sievetext
#endif

#ifdef yyleng
#define sieveleng_ALREADY_DEFINED
#else
#define yyleng sieveleng
#endif

#ifdef yyin
#define sievein_ALREADY_DEFINED
#else
#define yyin sievein
#endif

#ifdef yyout
#define sieveout_ALREADY_DEFINED
#else
#define yyout sieveout
#endif

#ifdef yy_flex_debug
#define sieve_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug sieve_flex_debug
#endif

#ifdef yylineno
#define sievelineno_ALREADY_DEFINED
#else
#define yylineno sievelineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define sievewrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 161
#define YY_END_OF_BUFFER 162
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[917] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  162,  160,  159,  159,    7,  158,  160,    8,
      160,  160,  160,  160,  160,  160,  160,  160,  160,  160,
      160,  160,  160,  160,  160,  160,  160,  160,  160,    5,
        5,    5,    3,    5,   32,   32,  160,   73,   73,  160,
      103,  103,  160,  158,    0,    8,    8,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    9,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    2,    2,    1,    4,
        0,   37,    0,    0,   80,    0,    0,    0,    0,    0,
      107,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   38,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,  142,    0,    0,
       19,    0,    0,    0,    0,    0,    0,    0,   56,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  104,  105,  106,    0,  157,
        0,   45,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  133,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   51,    0,    0,    0,  121,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,   50,    0,   86,    0,
        0,    0,   11,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   27,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   23,
        0,    0,   13,    0,    0,   18,    0,    0,    0,    0,
        0,   74,   77,   76,   79,   78,   75,  157,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   30,    0,    0,
       64,    0,    0,    0,    0,    0,    0,   67,    0,    0,
        0,    0,    0,    0,   91,    0,   43,    0,    0,    0,
        0,    0,   69,    0,  126,    0,    0,    0,    0,   24,

        0,    0,    0,    0,    0,    0,    0,    0,   52,  141,
        0,    0,    0,    0,   48,    0,    0,   88,    0,    0,
        0,   15,   14,    0,    0,    0,    0,   10,    0,    0,
        0,  109,    0,   17,    0,    0,    0,  108,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   71,    0,    0,    0,    0,    0,    0,   85,    0,
        0,    0,    0,   90,    0,    0,    0,   57,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   41,

        0,    0,    0,    0,   25,    0,    0,   58,   72,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       16,    0,    0,   20,    0,    0,    0,    0,    0,   98,
        0,    0,   94,    0,    0,  127,    0,    0,  136,    0,
       55,    0,    6,    6,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  118,    0,    0,    0,    0,    0,    0,
      111,    0,   49,   47,    0,  155,  124,   68,  129,    0,
        0,   62,    0,    0,    0,    0,    0,  120,    0,    0,
        0,    0,    0,    0,    0,  152,    0,    0,    0,    0,
        0,    0,    0,    0,   82,    0,   21,    0,    0,   26,

        0,    0,    0,   95,    0,   84,    0,  122,    0,    0,
        0,    0,    0,    0,    0,   12,    0,   81,    0,    0,
        6,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  119,    0,    0,    0,   53,    0,    0,    0,
        0,    0,    0,  137,   40,  100,    0,   99,    0,    0,
      151,    0,    0,    0,    0,   70,    0,   66,    0,    0,
        0,    0,    0,    0,    0,    0,   22,    0,   28,    0,
        0,    0,    0,  112,    0,    0,    0,   29,    0,    0,
        0,    6,   63,    0,    0,    0,    0,    0,  138,    0,
        0,    0,    0,    0,    0,   39,    0,    0,    0,    0,

        0,    0,    0,  125,    0,    0,  123,    0,    0,    0,
        0,  130,    0,    0,  140,   92,    0,    0,  128,    0,
        0,  143,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   33,    0,   65,    0,    0,    0,
        0,    0,    0,  101,    0,    0,   46,    0,  135,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   83,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  150,   31,
        0,  102,    0,   59,  149,    0,   42,    0,    0,  132,
        0,   60,   89,    0,   54,    0,    0,    0,    0,    0,

        0,  153,    0,    0,    0,    0,    0,    0,    0,  145,
        0,    0,    0,  146,    0,    0,  139,  147,   93,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   87,    0,    0,  110,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   61,    0,    0,  113,    0,    0,
      114,    0,   44,    0,    0,    0,    0,  117,  116,  154,
        0,    0,  134,    0,  144,    0,    0,    0,    0,    0,
        0,  148,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  131,    0,   34,   35,    0,    0,    0,

        0,    0,    0,    0,    0,    0,   97,   36,  156,    0,
      115,    0,    0,    0,   96,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    1,    1,
        1,    7,    1,    1,    8,    9,   10,   11,   12,   13,
       14,   11,   11,   11,   11,   11,   11,   15,   16,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
       17,    1,    1,    1,   17,    1,   17,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,   18,    1,    1,   19,    1,   20,   21,   22,   23,

       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
       44,   45,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[46] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[926] =
    {   0,
        0,    0, 1011,   43,   44,   45,   51,   55,   62,   66,
       70,   74, 1013, 1015, 1015, 1015, 1015,    0, 1005,   69,
       82,   61,  977,  970,  105,   54,   68,   69,  103,  977,
      984,  973,  114,  972,  968,  980,  113,   74,  983, 1015,
     1015,  140, 1015,    0, 1015, 1015,  126, 1015, 1015,  127,
     1015, 1015,  150,    0,  995,    0, 1015,  116,  957,  122,
      137,  132,  144,  969,  148,  141,  156,  158,  965,  152,
      974,  957,  171,  159,  143,  163,  976,  971,  960,  970,
      961,  947,  967,  952,  949,  956,  948,  950,  946,  942,
      173,  954,  950,  949,  941,  958, 1015,  957,  941,  953,

      954,  949,  946,  943,  931,  930,  934,  177,  165,  922,
      932,  941,  171,  921,  923,  181, 1015,  959, 1015, 1015,
      956, 1015,  202,  955, 1015,  206,  209,  210,  212,  954,
     1015,  953,  952,  951,  948,  212,  931,  922,  138,  921,
      188,  927,  906,  193,  917,  926,  910,  924,  925,  910,
      909,  909,  921,  905,  202, 1015,  901,  905,  899,  204,
      199,  898,  903,  895,  911,  893,  203,  892,  906,  892,
      894,  885,  215,  904,  901,  903,  880,  894,  216,   77,
      897,  889,  895,  885,  225,  883,  882,  871,  877,  889,
      888,  889,  879,  227,  229,  880,  874,  869,  868,  881,

      879,  880,  861,  870,  869,  864,  863, 1015,  866,  876,
      867,  872,  865,  868,  857,  850,  849,  847,  862,  862,
      851,  862,  848,  854,  842,  856,  859,  850,  225,  872,
      871,  870,  869,  868,  867, 1015, 1015, 1015,  230, 1015,
      231,  837,  836,  230,  845,  833,  828,  822,  832,  844,
      825,  838,  841,  840,  825,  820, 1015,  831,  824,  834,
      831,  830,  818,  827,  822,  810,  822,  808,  826,  821,
      813,  821,  804,  817,  812,  815,  810,  817,  810,  813,
      797,  795,  793, 1015,  793,  806,  795, 1015,  794,  805,
      797,  786,  801,  799,  786,  801,  796,  782,  778,  787,

      792,  784,  790,  789,  787,  786, 1015,  786, 1015,  770,
      788,  779, 1015,  781,  774,  767,  779,  765,  762,  776,
      771,  767,  773,  772,  767,  754,  757, 1015,  771,  768,
      765,  765,  751,  765,  745,  757,  747,  759,  751, 1015,
      736,  752, 1015,  746,  763, 1015,  738,  753,  255,  256,
      258, 1015, 1015, 1015, 1015, 1015, 1015,  768,  743,  749,
      730,  748,  738,  749,  735,  747,  246, 1015,  727,  726,
     1015,  725,  735,  734,  738,  721,  721, 1015,  738,  726,
      732,  718,  711,  714, 1015,  713, 1015,  720,  713,  728,
      721,  727, 1015,  721, 1015,  711,  711,  715,  708, 1015,

      707,  716,  705,  695,  696,  703,  707,  710, 1015, 1015,
      696,  692,  692,  693, 1015,  705,  705, 1015,  707,  706,
      687, 1015, 1015,  691,  699,  685,  699, 1015,  686,  685,
      696, 1015,  679, 1015,  683,  695,  677, 1015,  691,  689,
      671,  676,  689,  664,  669,  682,  666,  680,  666,  669,
      664,  680,  675,  678,  671,  269,  668,  676,  259,  264,
      269,  674,  655,  657,  667,  666,  667,  665,  650,  658,
      652, 1015,  660,  659,  651,  648,  656,  642, 1015,  647,
      653,  639,  636, 1015,  650,  646,  637,  646,  636,  645,
      642,  623,  633,  637,  631,  631,  629,  240,  628, 1015,

      636,  636,  638,  635, 1015,  632,  631,  629, 1015,  633,
      626,  628,  612,  610,  621,  624,  626,  610,  611,  604,
     1015,  603,  615, 1015,  612,  615,  614,  594,  597,  616,
      596,  611, 1015,  607,  607, 1015,  598,  603, 1015,  597,
     1015,  281, 1015,  624,  276,  592,  262,  271,  283,  284,
      599,  586,  583, 1015,  272,  598,  601,  600,  586,  579,
     1015,  595, 1015, 1015,  576, 1015, 1015, 1015, 1015,  595,
      576, 1015,  593,  584,  568,  572,  585, 1015,  270,  563,
      587,  582,  585,  580,  575, 1015,  577,  563,  569,  560,
      570,  559,  568,  551, 1015,  570, 1015,  570,  568, 1015,

      552,  566,  557, 1015,  554, 1015,  548, 1015,  549,  270,
      565,  552,  274,  544,  551, 1015,  557, 1015,  540,  297,
      301,  546,  535,  543,  305,  306,   56,  538,  551,  553,
      552,  548, 1015,  534,  531,  531, 1015,  548,  530,  533,
      531,  527,  526,  534, 1015, 1015,  530, 1015,  536,  528,
     1015,  527,  531,  525,  524, 1015,  514, 1015,  530,  518,
      514,  512,  512,  528,  527,  522, 1015,  521, 1015,  525,
      499,  499,  518,  516,  515,  518,  505, 1015,  516,  496,
      496, 1015, 1015,  494,  493,  307,  526,  308, 1015,  492,
      498,  490,  481,  483,  476, 1015,  476,  477,  485,  473,

      466,  466,  480, 1015,  465,  456, 1015,   27,  103,  120,
      112, 1015,  281,  278, 1015, 1015,  278,  295, 1015,  286,
      290, 1015,  293,  298,  280,  285,  294,  298,  301,  308,
      305,  311,  304,  329, 1015,  330, 1015,  308,  303,  318,
      316,  303,  319, 1015,  318,  312, 1015,  305, 1015,  308,
      313,  305,  327,  324,  328,  322,  316,  332,  333,  319,
      335,  322,  318,  335,  337,  341,  331, 1015,  344,  349,
      338,  345,  366,  367,  368,  352,  344,  338, 1015, 1015,
      354, 1015,  335, 1015, 1015,  347, 1015,  361,  344, 1015,
      339, 1015, 1015,  347, 1015,  361,  348,  360,  351,  356,

      358, 1015,  372,  369,  366,  351,  391,  392,  393, 1015,
      359,  372,  370, 1015,  378,  366, 1015, 1015, 1015,  369,
      367,  368,  369,  386,  387,  372,  369,  375,  395,  411,
      412,  413,  380,  379,  397, 1015,  399,  404, 1015,  386,
      388,  408,  410,  411,  404,  395,  405,  433,  434,  435,
      417,  418,  420,  420, 1015,  406,  408, 1015,  425,  411,
      425,  412, 1015,  427,  447,  448,  450, 1015, 1015, 1015,
      431,  436, 1015,  437, 1015,  415,  420,  421,  456,  457,
      458, 1015,  427,  431,  440,  431,  443,  467,  470,  472,
      452,  460,  443, 1015,  448, 1015, 1015,  478,  460,  464,

      447,  464,  483,  450,  465,  456, 1015, 1015, 1015,  464,
     1015,  468,  458,  454, 1015, 1015,  513,  515,  498,  499,
      517,  519,  521,  523,  525
    } ;

static const flex_int16_t yy_def[926] =
    {   0,
      916,    1,  917,  917,  917,  917,  918,  918,  918,  918,
      918,  918,  916,  916,  916,  916,  916,  919,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  920,  916,  916,  921,  916,  916,  922,
      916,  916,  923,  919,  924,   20,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,

      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      921,  916,  921,  922,  916,  922,  922,  922,  922,  923,
      916,  923,  923,  923,  924,  924,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,

      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  921,  922,
      922,  922,  922,  922,  922,  916,  916,  916,  924,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,

      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  921,  921,
      921,  916,  916,  916,  916,  916,  916,  924,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,

      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  921,  921,
      921,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,

      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  925,  916,  916,  921,  921,  921,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,

      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  925,
      925,  916,  916,  916,  921,  921,  921,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  921,  921,  921,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,

      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  921,  916,  921,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  921,  921,  921,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,

      916,  916,  916,  916,  916,  916,  921,  921,  921,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  921,
      921,  921,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  921,  921,  921,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  921,  921,  921,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  921,  921,
      921,  916,  916,  916,  916,  916,  916,  921,  921,  921,
      916,  916,  916,  916,  916,  916,  916,  921,  916,  916,

      916,  916,  921,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,    0,  916,  916,  916,  916,
      916,  916,  916,  916,  916
    } ;

static const flex_int16_t yy_nxt[1061] =
    {   0,
       14,   15,   16,   15,   17,   18,   14,   14,   14,   19,
       20,   20,   20,   20,   21,   14,   14,   14,   14,   22,
       23,   24,   25,   26,   27,   14,   28,   29,   30,   31,
       32,   33,   34,   14,   35,   14,   36,   37,   38,   14,
       39,   14,   14,   14,   14,   41,   41,   41,   43,   43,
      752,   42,   45,   46,   45,   47,   45,   46,   45,   47,
      122,   44,   44,   48,   49,   48,   50,   48,   49,   48,
       50,   51,   52,   51,   53,   51,   52,   51,   53,   56,
       56,   56,   56,   80,   89,   57,   90,   93,   95,  688,
       91,   81,   96,   82,   57,   94,   92,  114,   57,  296,

       57,   58,   59,   60,   61,   62,   63,   64,   65,   66,
      115,  297,   67,   68,   69,   70,   71,   72,   73,   74,
       75,   76,   77,   78,   85,  753,   79,   97,   86,   98,
      122,  125,   87,  104,   99,  100,  109,  105,  137,  754,
      110,  140,  117,  118,   88,  111,  138,  112,  119,  755,
      126,  113,  127,  123,  131,  141,  143,  128,  142,  129,
      144,  132,  133,  134,  146,  148,  177,  152,  147,  243,
      145,  153,  154,  155,  149,  157,  244,  161,  156,  158,
      150,  162,  174,  159,  165,  163,  166,  178,  167,  160,
      172,  168,  169,  175,  173,  179,  196,  180,  176,  213,

      181,  218,  227,  219,  223,  214,  122,  224,  215,  197,
      125,  228,  216,  125,  125,  217,  125,  229,  239,  246,
      247,  240,  248,  252,  264,  269,  271,  249,  278,  122,
      279,  253,  231,  233,  285,  235,  136,  272,  294,  358,
      286,  230,  265,  295,  349,  270,  287,  232,  234,  302,
      313,  303,  315,  288,  314,  359,  316,  363,  350,  122,
      122,  304,  122,  122,  351,  470,  364,  360,  122,  471,
      542,  543,  544,  122,  545,  122,  584,  460,  543,  621,
      548,  585,  542,  543,  544,  623,  545,  122,  122,  647,
      461,  631,  459,  672,  624,  676,  550,  673,  625,  543,

      621,  677,  549,  682,  621,  627,  626,  648,  632,  122,
      122,  122,  122,  756,  734,  757,  758,  759,  760,  761,
      762,  763,  764,  765,  766,  767,  768,  769,  770,  771,
      736,  772,  686,  122,  122,  776,  777,  778,  779,  780,
      781,  782,  783,  784,  687,  785,  786,  787,  788,  789,
      773,  790,  791,  775,  792,  793,  794,  795,  796,  797,
      798,  774,  799,  800,  801,  802,  803,  804,  805,  806,
      122,  122,  122,  810,  811,  809,  812,  813,  814,  815,
      816,  817,  818,  819,  820,  807,  821,  822,  823,  824,
      825,  826,  827,  828,  829,  122,  122,  122,  833,  834,

      835,  836,  837,  838,  839,  840,  808,  841,  842,  843,
      844,  845,  846,  847,  832,  122,  122,  122,  851,  852,
      853,  855,  856,  831,  857,  858,  859,  854,  830,  860,
      861,  862,  850,  863,  848,  849,  864,  122,  122,  122,
      868,  869,  870,  871,  872,  873,  874,  875,  876,  877,
      878,  122,  122,  882,  122,  883,  884,  885,  886,  887,
      122,  122,  122,  891,  865,  892,  879,  893,  894,  895,
      866,  896,  867,  881,  897,  880,  122,  899,  889,  900,
      901,  902,  122,  904,  905,  906,  907,  908,  909,  890,
      888,  898,  910,  911,  912,  913,  914,  915,   54,  120,

      751,  750,  749,  748,  747,  746,  745,  744,  743,  742,
      741,  740,  903,   40,   40,   14,   14,  121,  121,  124,
      124,  130,  130,  135,  135,  620,  620,  739,  738,  737,
      735,  733,  732,  731,  730,  729,  728,  727,  726,  725,
      724,  723,  722,  721,  720,  719,  718,  717,  716,  715,
      714,  713,  712,  711,  710,  709,  708,  707,  706,  705,
      704,  703,  702,  701,  700,  699,  698,  697,  696,  695,
      694,  693,  692,  691,  690,  689,  685,  684,  683,  681,
      680,  679,  678,  675,  674,  671,  670,  669,  668,  667,
      666,  665,  664,  663,  662,  661,  660,  659,  658,  657,

      656,  655,  654,  653,  652,  651,  650,  649,  646,  645,
      644,  643,  642,  641,  640,  639,  638,  637,  636,  635,
      634,  633,  630,  629,  628,  622,  543,  619,  618,  617,
      616,  615,  614,  613,  612,  611,  610,  609,  608,  607,
      606,  605,  604,  603,  602,  601,  600,  599,  598,  597,
      596,  595,  594,  593,  592,  591,  590,  589,  588,  587,
      586,  583,  582,  581,  580,  579,  578,  577,  576,  575,
      574,  573,  572,  571,  570,  569,  568,  567,  566,  565,
      564,  563,  562,  561,  560,  559,  558,  557,  556,  555,
      554,  553,  552,  551,  547,  546,  541,  540,  539,  538,

      537,  536,  535,  534,  533,  532,  531,  530,  529,  528,
      527,  526,  525,  524,  523,  522,  521,  520,  519,  518,
      517,  516,  515,  514,  513,  512,  511,  510,  509,  508,
      507,  506,  505,  504,  503,  502,  501,  500,  499,  498,
      497,  496,  495,  494,  493,  492,  491,  490,  489,  488,
      487,  486,  485,  484,  483,  482,  481,  480,  479,  478,
      477,  476,  475,  474,  473,  472,  469,  468,  467,  466,
      465,  464,  463,  462,  136,  458,  457,  456,  455,  454,
      453,  452,  451,  450,  449,  448,  447,  446,  445,  444,
      443,  442,  441,  440,  439,  438,  437,  436,  435,  434,

      433,  432,  431,  430,  429,  428,  427,  426,  425,  424,
      423,  422,  421,  420,  419,  418,  417,  416,  415,  414,
      413,  412,  411,  410,  409,  408,  407,  406,  405,  404,
      403,  402,  401,  400,  399,  398,  397,  396,  395,  394,
      393,  392,  391,  390,  389,  388,  387,  386,  385,  384,
      383,  382,  381,  380,  379,  378,  377,  376,  375,  374,
      373,  372,  371,  370,  369,  368,  367,  366,  365,  362,
      361,  357,  356,  355,  354,  353,  352,  348,  347,  346,
      345,  344,  343,  342,  341,  340,  339,  338,  337,  336,
      335,  334,  333,  332,  331,  330,  329,  328,  327,  326,

      325,  324,  323,  322,  321,  320,  319,  318,  317,  312,
      311,  310,  309,  308,  307,  306,  305,  301,  300,  299,
      298,  293,  292,  291,  290,  289,  284,  283,  282,  281,
      280,  277,  276,  275,  274,  273,  268,  267,  266,  263,
      262,  261,  260,  259,  258,  257,  256,  255,  254,  251,
      250,  245,  242,  241,  136,  238,  237,  236,  131,  125,
      122,  117,  226,  225,  222,  221,  220,  212,  211,  210,
      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  195,  194,  193,  192,  191,  190,  189,  188,
      187,  186,  185,  184,  183,  182,  171,  170,  164,  151,

      139,  136,  116,  108,  107,  106,  103,  102,  101,   84,
       83,   55,  916,   41,   13,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916
    } ;

static const flex_int16_t yy_chk[1061] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    4,    5,    6,    5,    6,
      708,    4,    7,    7,    7,    7,    8,    8,    8,    8,
      627,    5,    6,    9,    9,    9,    9,   10,   10,   10,
       10,   11,   11,   11,   11,   12,   12,   12,   12,   20,
       20,   20,   20,   22,   26,   20,   26,   27,   28,  627,
       26,   22,   28,   22,   20,   27,   26,   38,   20,  180,

       20,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       38,  180,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   25,  709,   21,   29,   25,   29,
       47,   50,   25,   33,   29,   29,   37,   33,   58,  710,
       37,   60,   42,   42,   25,   37,   58,   37,   42,  711,
       50,   37,   50,   47,   53,   60,   61,   50,   60,   50,
       61,   53,   53,   53,   62,   63,   75,   65,   62,  139,
       61,   65,   66,   66,   63,   67,  139,   68,   66,   67,
       63,   68,   74,   67,   70,   68,   70,   75,   70,   67,
       73,   70,   70,   74,   73,   76,   91,   76,   74,  108,

       76,  109,  116,  109,  113,  108,  123,  113,  108,   91,
      126,  116,  108,  127,  128,  108,  129,  123,  136,  141,
      141,  136,  141,  144,  155,  160,  161,  141,  167,  229,
      167,  144,  127,  128,  173,  129,  239,  161,  179,  239,
      173,  126,  155,  179,  229,  160,  173,  127,  128,  185,
      194,  185,  195,  173,  194,  241,  195,  244,  229,  349,
      350,  185,  351,  459,  229,  367,  244,  241,  460,  367,
      456,  456,  456,  461,  456,  548,  498,  350,  545,  545,
      459,  498,  542,  542,  542,  547,  542,  549,  550,  579,
      351,  555,  349,  610,  547,  613,  461,  610,  548,  620,

      620,  613,  460,  621,  621,  550,  549,  579,  555,  625,
      626,  686,  688,  713,  686,  714,  717,  718,  720,  721,
      723,  724,  725,  726,  727,  728,  729,  730,  731,  732,
      688,  733,  625,  734,  736,  738,  739,  740,  741,  742,
      743,  745,  746,  748,  626,  750,  751,  752,  753,  754,
      734,  755,  756,  736,  757,  758,  759,  760,  761,  762,
      763,  734,  764,  765,  766,  767,  769,  770,  771,  772,
      773,  774,  775,  776,  777,  775,  778,  781,  783,  786,
      788,  789,  791,  794,  796,  773,  797,  798,  799,  800,
      801,  803,  804,  805,  806,  807,  808,  809,  811,  812,

      813,  815,  816,  820,  821,  822,  774,  823,  824,  825,
      826,  827,  828,  829,  809,  830,  831,  832,  833,  834,
      835,  837,  838,  808,  840,  841,  842,  835,  807,  843,
      844,  845,  832,  846,  830,  831,  847,  848,  849,  850,
      851,  852,  853,  854,  856,  857,  859,  860,  861,  862,
      864,  865,  866,  871,  867,  872,  874,  876,  877,  878,
      879,  880,  881,  883,  848,  884,  865,  885,  886,  887,
      849,  888,  850,  867,  889,  866,  890,  891,  880,  892,
      893,  895,  898,  899,  900,  901,  902,  903,  904,  881,
      879,  890,  905,  906,  910,  912,  913,  914,  919,  920,

      706,  705,  703,  702,  701,  700,  699,  698,  697,  695,
      694,  693,  898,  917,  917,  918,  918,  921,  921,  922,
      922,  923,  923,  924,  924,  925,  925,  692,  691,  690,
      687,  685,  684,  681,  680,  679,  677,  676,  675,  674,
      673,  672,  671,  670,  668,  666,  665,  664,  663,  662,
      661,  660,  659,  657,  655,  654,  653,  652,  650,  649,
      647,  644,  643,  642,  641,  640,  639,  638,  636,  635,
      634,  632,  631,  630,  629,  628,  624,  623,  622,  619,
      617,  615,  614,  612,  611,  609,  607,  605,  603,  602,
      601,  599,  598,  596,  594,  593,  592,  591,  590,  589,

      588,  587,  585,  584,  583,  582,  581,  580,  577,  576,
      575,  574,  573,  571,  570,  565,  562,  560,  559,  558,
      557,  556,  553,  552,  551,  546,  544,  540,  538,  537,
      535,  534,  532,  531,  530,  529,  528,  527,  526,  525,
      523,  522,  520,  519,  518,  517,  516,  515,  514,  513,
      512,  511,  510,  508,  507,  506,  504,  503,  502,  501,
      499,  497,  496,  495,  494,  493,  492,  491,  490,  489,
      488,  487,  486,  485,  483,  482,  481,  480,  478,  477,
      476,  475,  474,  473,  471,  470,  469,  468,  467,  466,
      465,  464,  463,  462,  458,  457,  455,  454,  453,  452,

      451,  450,  449,  448,  447,  446,  445,  444,  443,  442,
      441,  440,  439,  437,  436,  435,  433,  431,  430,  429,
      427,  426,  425,  424,  421,  420,  419,  417,  416,  414,
      413,  412,  411,  408,  407,  406,  405,  404,  403,  402,
      401,  399,  398,  397,  396,  394,  392,  391,  390,  389,
      388,  386,  384,  383,  382,  381,  380,  379,  377,  376,
      375,  374,  373,  372,  370,  369,  366,  365,  364,  363,
      362,  361,  360,  359,  358,  348,  347,  345,  344,  342,
      341,  339,  338,  337,  336,  335,  334,  333,  332,  331,
      330,  329,  327,  326,  325,  324,  323,  322,  321,  320,

      319,  318,  317,  316,  315,  314,  312,  311,  310,  308,
      306,  305,  304,  303,  302,  301,  300,  299,  298,  297,
      296,  295,  294,  293,  292,  291,  290,  289,  287,  286,
      285,  283,  282,  281,  280,  279,  278,  277,  276,  275,
      274,  273,  272,  271,  270,  269,  268,  267,  266,  265,
      264,  263,  262,  261,  260,  259,  258,  256,  255,  254,
      253,  252,  251,  250,  249,  248,  247,  246,  245,  243,
      242,  235,  234,  233,  232,  231,  230,  228,  227,  226,
      225,  224,  223,  222,  221,  220,  219,  218,  217,  216,
      215,  214,  213,  212,  211,  210,  209,  207,  206,  205,

      204,  203,  202,  201,  200,  199,  198,  197,  196,  193,
      192,  191,  190,  189,  188,  187,  186,  184,  183,  182,
      181,  178,  177,  176,  175,  174,  172,  171,  170,  169,
      168,  166,  165,  164,  163,  162,  159,  158,  157,  154,
      153,  152,  151,  150,  149,  148,  147,  146,  145,  143,
      142,  140,  138,  137,  135,  134,  133,  132,  130,  124,
      121,  118,  115,  114,  112,  111,  110,  107,  106,  105,
      104,  103,  102,  101,  100,   99,   98,   96,   95,   94,
       93,   92,   90,   89,   88,   87,   86,   85,   84,   83,
       82,   81,   80,   79,   78,   77,   72,   71,   69,   64,

       59,   55,   39,   36,   35,   34,   32,   31,   30,   24,
       23,   19,   13,    3,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916,
      916,  916,  916,  916,  916,  916,  916,  916,  916,  916
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[162] =
    {   0,
0, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 
    0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "sieve/sieve-lex.l"
#line 2 "sieve/sieve-lex.l"
/* sieve.l -- sieve lexer
 * Larry Greenfield
 * Ken Murchison
 *
 * Copyright (c) 1994-2017 Carnegie Mellon University.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The name "Carnegie Mellon University" must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission. For permission or any legal
 *    details, please contact
 *      Carnegie Mellon University
 *      Center for Technology Transfer and Enterprise Creation
 *      4615 Forbes Avenue
 *      Suite 302
 *      Pittsburgh, PA  15213
 *      (412) 268-7393, fax: (412) 268-7395
 *      innovation@andrew.cmu.edu
 *
 * 4. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by Computing Services
 *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
 *
 * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
 * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <strings.h>
#include "util.h"

#include "sieve/tree.h"
#include "sieve/sieve_interface.h"
#include "sieve/sieve.h"

#define YY_NO_INPUT
#define YY_DECL int yylex(YYSTYPE *yylval, sieve_script_t *sscript)

static struct buf buf;   /* buffer for multi-line text and quoted strings */
extern int encoded_char; /* used to receive encoded-char feedback from parser */

static unsigned long long tonum(const char *str);
static int decode_string(struct buf *buf);
extern void sieveerror(sieve_script_t *, const char *);
extern void sieveerror_f(sieve_script_t *, const char *fmt, ...);
#line 1338 "sieve/sieve-lex.c"
#line 75 "sieve/sieve-lex.l"
    /* linebreak */
    /* non-linebreaking whitespace */





#line 1347 "sieve/sieve-lex.c"

#define INITIAL 0
#define MULTILINE 1
#define QSTRING 2
#define QCOLLATION 3
#define QRELATION 4
#define QIMPORTANCE 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 87 "sieve/sieve-lex.l"

    /* dot stuffing */
#line 1573 "sieve/sieve-lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 917 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1015 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 89 "sieve/sieve-lex.l"
buf_putc(&buf, yytext[1]);
	YY_BREAK
/* end of multi-line text */
case 2:
/* rule 2 can match eol */
#line 93 "sieve/sieve-lex.l"
/* end of quoted string */
case 3:
YY_RULE_SETUP
#line 95 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  if (encoded_char && !decode_string(&buf)) {
                                      sieveerror_f(sscript,
                                                   "invalid unicode encoding: %s",
                                                   buf_cstring(&buf));
                                  }
                                  yylval->sval = buf_release(&buf);
                                  return STRING;
                              }
	YY_BREAK
/* escaped character */
case 4:
YY_RULE_SETUP
#line 107 "sieve/sieve-lex.l"
buf_putc(&buf, yytext[1]);
	YY_BREAK
/* any character (including LF) */
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 110 "sieve/sieve-lex.l"
buf_putc(&buf, yytext[0]);
	YY_BREAK
/* premature EOF */
case YY_STATE_EOF(QSTRING):
case YY_STATE_EOF(MULTILINE):
#line 113 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror(sscript,
                                             "unexpected end of file in string");
                                  buf_free(&buf);
                                  yyterminate();
                              }
	YY_BREAK
/* beginning of multi-line text */
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 122 "sieve/sieve-lex.l"
{
                                  BEGIN MULTILINE;
                                  buf_reset(&buf);
                              }
	YY_BREAK
/* beginning of quoted string */
case 7:
YY_RULE_SETUP
#line 128 "sieve/sieve-lex.l"
{
                                  BEGIN QSTRING;
                                  buf_reset(&buf);
                              }
	YY_BREAK
/* number with optional power of 2 suffix */
case 8:
YY_RULE_SETUP
#line 134 "sieve/sieve-lex.l"
{
                                  unsigned long long val = tonum(yytext);
                                  if (val > INT_MAX) {
                                      sieveerror_f(sscript,
                                                   "number too large %s",
                                                   yytext);
                                  }
                                  yylval->nval = val;
                                  return NUMBER;
                              }
	YY_BREAK
/* standard control commands - RFC 5228 */
case 9:
YY_RULE_SETUP
#line 146 "sieve/sieve-lex.l"
return IF;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 147 "sieve/sieve-lex.l"
return ELSIF;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 148 "sieve/sieve-lex.l"
return ELSE;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 149 "sieve/sieve-lex.l"
return REQUIRE;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 150 "sieve/sieve-lex.l"
return STOP;
	YY_BREAK
/* standard tests - RFC 5228 */
case 14:
YY_RULE_SETUP
#line 153 "sieve/sieve-lex.l"
return ANYOF;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 154 "sieve/sieve-lex.l"
return ALLOF;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 155 "sieve/sieve-lex.l"
return EXISTS;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 156 "sieve/sieve-lex.l"
return SFALSE;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 157 "sieve/sieve-lex.l"
return STRUE;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 158 "sieve/sieve-lex.l"
return NOT;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 159 "sieve/sieve-lex.l"
return HEADERT;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 160 "sieve/sieve-lex.l"
return ADDRESS;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 161 "sieve/sieve-lex.l"
return ENVELOPE;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 162 "sieve/sieve-lex.l"
return SIZE;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 163 "sieve/sieve-lex.l"
return yylval->nval = OVER;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 164 "sieve/sieve-lex.l"
return yylval->nval = UNDER;
	YY_BREAK
/* standard action commands - RFC 5228 */
case 26:
YY_RULE_SETUP
#line 167 "sieve/sieve-lex.l"
return DISCARD;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 168 "sieve/sieve-lex.l"
return KEEP;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 169 "sieve/sieve-lex.l"
return FILEINTO;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 170 "sieve/sieve-lex.l"
return REDIRECT;
	YY_BREAK
/* copy - RFC 3894 */
case 30:
YY_RULE_SETUP
#line 173 "sieve/sieve-lex.l"
return COPY;
	YY_BREAK
/* comparator-types - RFC 5228 */
case 31:
YY_RULE_SETUP
#line 176 "sieve/sieve-lex.l"
{ BEGIN QCOLLATION; return COMPARATOR; }
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 178 "sieve/sieve-lex.l"
;       /* ignore whitespace */
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 179 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  return yylval->nval = OCTET;
                              }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 183 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  return yylval->nval = ASCIICASEMAP;
                              }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 187 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  return yylval->nval = ASCIINUMERIC;
                              }
	YY_BREAK
/* RFC 5051 */
case 36:
YY_RULE_SETUP
#line 192 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  return yylval->nval = UNICODECASEMAP;
                              }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 196 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror_f(sscript,
                                               "unknown comparator-name %s",
                                               yytext);
                              }
	YY_BREAK
/* match-types - RFC 5228 */
case 38:
YY_RULE_SETUP
#line 204 "sieve/sieve-lex.l"
return yylval->nval = IS;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 205 "sieve/sieve-lex.l"
return yylval->nval = CONTAINS;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 206 "sieve/sieve-lex.l"
return yylval->nval = MATCHES;
	YY_BREAK
/* regex - draft-ietf-sieve-regex */
case 41:
YY_RULE_SETUP
#line 209 "sieve/sieve-lex.l"
return yylval->nval = REGEX;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 210 "sieve/sieve-lex.l"
return yylval->nval = QUOTEREGEX;
	YY_BREAK
/* extlists - RFC 6134 */
case 43:
YY_RULE_SETUP
#line 213 "sieve/sieve-lex.l"
return yylval->nval = LIST;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 214 "sieve/sieve-lex.l"
return VALIDEXTLIST;
	YY_BREAK
/* address-parts - RFC 5228 */
case 45:
YY_RULE_SETUP
#line 217 "sieve/sieve-lex.l"
return yylval->nval = ALL;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 218 "sieve/sieve-lex.l"
return yylval->nval = LOCALPART;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 219 "sieve/sieve-lex.l"
return yylval->nval = DOMAIN;
	YY_BREAK
/* subaddress - RFC 5233 */
case 48:
YY_RULE_SETUP
#line 222 "sieve/sieve-lex.l"
return yylval->nval = USER;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 223 "sieve/sieve-lex.l"
return yylval->nval = DETAIL;
	YY_BREAK
/* body - RFC 5173 */
case 50:
YY_RULE_SETUP
#line 226 "sieve/sieve-lex.l"
return BODY;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 227 "sieve/sieve-lex.l"
return yylval->nval = RAW;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 228 "sieve/sieve-lex.l"
return yylval->nval = TEXT;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 229 "sieve/sieve-lex.l"
return yylval->nval = CONTENT;
	YY_BREAK
/* environment - RFC 5183 */
case 54:
YY_RULE_SETUP
#line 232 "sieve/sieve-lex.l"
return ENVIRONMENT;
	YY_BREAK
/* variables - RFC 5229 */
case 55:
YY_RULE_SETUP
#line 235 "sieve/sieve-lex.l"
return STRINGT;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 236 "sieve/sieve-lex.l"
return SET;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 237 "sieve/sieve-lex.l"
return yylval->nval = LOWER;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 238 "sieve/sieve-lex.l"
return yylval->nval = UPPER;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 239 "sieve/sieve-lex.l"
return yylval->nval = LOWERFIRST;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 240 "sieve/sieve-lex.l"
return yylval->nval = UPPERFIRST;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 241 "sieve/sieve-lex.l"
return yylval->nval = QUOTEWILDCARD;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 242 "sieve/sieve-lex.l"
return yylval->nval = LENGTH;
	YY_BREAK
/* vacation - RFC 5230 */
case 63:
YY_RULE_SETUP
#line 245 "sieve/sieve-lex.l"
return VACATION;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 246 "sieve/sieve-lex.l"
return DAYS;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 247 "sieve/sieve-lex.l"
return ADDRESSES;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 248 "sieve/sieve-lex.l"
return SUBJECT;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 249 "sieve/sieve-lex.l"
return FROM;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 250 "sieve/sieve-lex.l"
return HANDLE;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 251 "sieve/sieve-lex.l"
return MIME;
	YY_BREAK
/* vacation-seconds - RFC 6131 */
case 70:
YY_RULE_SETUP
#line 254 "sieve/sieve-lex.l"
return SECONDS;
	YY_BREAK
/* relational - RFC 5231 */
case 71:
YY_RULE_SETUP
#line 257 "sieve/sieve-lex.l"
{ BEGIN QRELATION; return yylval->nval = COUNT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 258 "sieve/sieve-lex.l"
{ BEGIN QRELATION; return yylval->nval = VALUE; }
	YY_BREAK
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
#line 260 "sieve/sieve-lex.l"
;        /* ignore whitespace */
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 261 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = EQ; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 262 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = NE; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 263 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = GT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 264 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = GE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 265 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = LT; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 266 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = LE; }
	YY_BREAK
case 80:
/* rule 80 can match eol */
YY_RULE_SETUP
#line 267 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror_f(sscript,
                                               "invalid relational-match %s",
                                               yytext);
                              }
	YY_BREAK
/* imap4flags - RFC 5232 */
case 81:
YY_RULE_SETUP
#line 275 "sieve/sieve-lex.l"
return yylval->nval = SETFLAG;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 276 "sieve/sieve-lex.l"
return yylval->nval = ADDFLAG;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 277 "sieve/sieve-lex.l"
return yylval->nval = REMOVEFLAG;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 278 "sieve/sieve-lex.l"
return yylval->nval = HASFLAG;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 279 "sieve/sieve-lex.l"
return FLAGS;
	YY_BREAK
/* date - RFC 5260 */
case 86:
YY_RULE_SETUP
#line 282 "sieve/sieve-lex.l"
return DATE;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 283 "sieve/sieve-lex.l"
return ORIGINALZONE;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 284 "sieve/sieve-lex.l"
return ZONE;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 285 "sieve/sieve-lex.l"
return CURRENTDATE;
	YY_BREAK
/* index - RFC 5260 */
case 90:
YY_RULE_SETUP
#line 288 "sieve/sieve-lex.l"
return INDEX;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 289 "sieve/sieve-lex.l"
return LAST;
	YY_BREAK
/* editheader - RFC 5293 */
case 92:
YY_RULE_SETUP
#line 292 "sieve/sieve-lex.l"
return ADDHEADER;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 293 "sieve/sieve-lex.l"
return DELETEHEADER;
	YY_BREAK
/*   :index               defined in 'index' */
/*   :last                defined in 'index' */
/* [e]reject - RFC 5429 */
case 94:
YY_RULE_SETUP
#line 298 "sieve/sieve-lex.l"
return yylval->nval = REJCT;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 299 "sieve/sieve-lex.l"
return yylval->nval = EREJECT;
	YY_BREAK
/* enotify - RFC 5435 */
case 96:
YY_RULE_SETUP
#line 302 "sieve/sieve-lex.l"
return NOTIFYMETHODCAPABILITY;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 303 "sieve/sieve-lex.l"
return VALIDNOTIFYMETHOD;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 304 "sieve/sieve-lex.l"
return NOTIFY;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 305 "sieve/sieve-lex.l"
return OPTIONS;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 306 "sieve/sieve-lex.l"
return MESSAGE;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 307 "sieve/sieve-lex.l"
return yylval->nval = ENCODEURL;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 308 "sieve/sieve-lex.l"
{ BEGIN QIMPORTANCE; return IMPORTANCE; }
	YY_BREAK
case 103:
/* rule 103 can match eol */
YY_RULE_SETUP
#line 310 "sieve/sieve-lex.l"
;      /* ignore whitespace */
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 311 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = HIGH;   }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 312 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = NORMAL; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 313 "sieve/sieve-lex.l"
{ BEGIN INITIAL; return yylval->nval = LOW;    }
	YY_BREAK
case 107:
/* rule 107 can match eol */
YY_RULE_SETUP
#line 314 "sieve/sieve-lex.l"
{
                                  BEGIN INITIAL;
                                  sieveerror_f(sscript,
                                               "invalid importance %s", yytext);
                              }
	YY_BREAK
/* ihave - RFC 5463 */
case 108:
YY_RULE_SETUP
#line 321 "sieve/sieve-lex.l"
return IHAVE;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 322 "sieve/sieve-lex.l"
return ERROR;
	YY_BREAK
/* mailbox - RFC 5490 */
case 110:
YY_RULE_SETUP
#line 325 "sieve/sieve-lex.l"
return MAILBOXEXISTS;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 326 "sieve/sieve-lex.l"
return CREATE;
	YY_BREAK
/* mboxmetadata - RFC 5490 */
case 112:
YY_RULE_SETUP
#line 329 "sieve/sieve-lex.l"
return yylval->nval = METADATA;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 330 "sieve/sieve-lex.l"
return METADATAEXISTS;
	YY_BREAK
/* servermetadata - RFC 5490 */
case 114:
YY_RULE_SETUP
#line 333 "sieve/sieve-lex.l"
return yylval->nval = SERVERMETADATA;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 334 "sieve/sieve-lex.l"
return SERVERMETADATAEXISTS;
	YY_BREAK
/* redirect-deliverby - RFC 6009 */
case 116:
YY_RULE_SETUP
#line 337 "sieve/sieve-lex.l"
return BYTIMEREL;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 338 "sieve/sieve-lex.l"
return BYTIMEABS;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 339 "sieve/sieve-lex.l"
return BYMODE;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 340 "sieve/sieve-lex.l"
return BYTRACE;
	YY_BREAK
/* redirect-dsn - RFC 6009 */
case 120:
YY_RULE_SETUP
#line 343 "sieve/sieve-lex.l"
return DSNNOTIFY;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 344 "sieve/sieve-lex.l"
return DSNRET;
	YY_BREAK
/* include - RFC 6609 */
case 122:
YY_RULE_SETUP
#line 347 "sieve/sieve-lex.l"
return INCLUDE;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 348 "sieve/sieve-lex.l"
return yylval->nval = PERSONAL;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 349 "sieve/sieve-lex.l"
return yylval->nval = GLOBAL;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 350 "sieve/sieve-lex.l"
return OPTIONAL;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 351 "sieve/sieve-lex.l"
return ONCE;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 352 "sieve/sieve-lex.l"
return RETURN;
	YY_BREAK
/* duplicate - RFC 7352 */
case 128:
YY_RULE_SETUP
#line 355 "sieve/sieve-lex.l"
return DUPLICATE;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 356 "sieve/sieve-lex.l"
return yylval->nval = HEADER;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 357 "sieve/sieve-lex.l"
return yylval->nval = UNIQUEID;
	YY_BREAK
/*   :handle              defined in 'vacation'         */
/*   :seconds             defined in 'vacation-seconds' */
/*   :last                defined in 'index'            */
/* special-use - RFC 8579 */
case 131:
YY_RULE_SETUP
#line 363 "sieve/sieve-lex.l"
return SPECIALUSEEXISTS;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 364 "sieve/sieve-lex.l"
return SPECIALUSE;
	YY_BREAK
/* fcc - RFC 8580 */
case 133:
YY_RULE_SETUP
#line 367 "sieve/sieve-lex.l"
return FCC;
	YY_BREAK
/* mailboxid - RFC 9042 */
case 134:
YY_RULE_SETUP
#line 370 "sieve/sieve-lex.l"
return MAILBOXIDEXISTS;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 371 "sieve/sieve-lex.l"
return MAILBOXID;
	YY_BREAK
/* snooze - draft-ietf-extra-sieve-snooze */
case 136:
YY_RULE_SETUP
#line 374 "sieve/sieve-lex.l"
return SNOOZE;
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 375 "sieve/sieve-lex.l"
return MAILBOX;
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 376 "sieve/sieve-lex.l"
return ADDFLAGS;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 377 "sieve/sieve-lex.l"
return REMOVEFLAGS;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 378 "sieve/sieve-lex.l"
return WEEKDAYS;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 379 "sieve/sieve-lex.l"
return TZID;
	YY_BREAK
/*   :create               defined in 'mailbox'     */
/*   :mailboxid            defined in 'mailboxid'   */
/*   :specialuse           defined in 'special-use' */
/* vnd.cyrus.log */
case 142:
YY_RULE_SETUP
#line 385 "sieve/sieve-lex.l"
return LOG;
	YY_BREAK
/* vnd.cyrus.jmapquery */
case 143:
YY_RULE_SETUP
#line 388 "sieve/sieve-lex.l"
return JMAPQUERY;
	YY_BREAK
/* processcalendar - RFC 9671 */
case 144:
YY_RULE_SETUP
#line 391 "sieve/sieve-lex.l"
return PROCESSCAL;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 392 "sieve/sieve-lex.l"
return ALLOWPUBLIC;
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 393 "sieve/sieve-lex.l"
return INVITESONLY;  /* Fastmail-specific */
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 394 "sieve/sieve-lex.l"
return UPDATESONLY;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 395 "sieve/sieve-lex.l"
return DELETECANCELLED;
	YY_BREAK
/*   :addresses            defined in 'vacation'    */
case 149:
YY_RULE_SETUP
#line 397 "sieve/sieve-lex.l"
return ORGANIZERS;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 398 "sieve/sieve-lex.l"
return CALENDARID;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 399 "sieve/sieve-lex.l"
return OUTCOME;
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 400 "sieve/sieve-lex.l"
return REASON;
	YY_BREAK
/* vnd.cyrus.imip (processcalendar precursor) */
case 153:
YY_RULE_SETUP
#line 403 "sieve/sieve-lex.l"
return PROCESSIMIP;
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 404 "sieve/sieve-lex.l"
return DELETECANCELLED;
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 405 "sieve/sieve-lex.l"
return REASON;
	YY_BREAK
/* vnd.cyrus.implicit_keep_target */
case 156:
YY_RULE_SETUP
#line 408 "sieve/sieve-lex.l"
return IKEEP_TARGET;
	YY_BREAK
/*   :mailboxid            defined in 'mailboxid'   */
/*   :specialuse           defined in 'special-use' */
case 157:
/* rule 157 can match eol */
YY_RULE_SETUP
#line 412 "sieve/sieve-lex.l"
;  /* ignore bracketed comments */
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 413 "sieve/sieve-lex.l"
;                /* ignore hash comments */
	YY_BREAK
case 159:
/* rule 159 can match eol */
YY_RULE_SETUP
#line 414 "sieve/sieve-lex.l"
;          /* ignore whitespace */
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 415 "sieve/sieve-lex.l"
{
                                  /* RFC 5228: With the exceptions of strings
                                     and comments, the language is limited to
                                     US-ASCII characters. */
                                  if (yytext[0] & ~0x7f) {
                                      sieveerror(sscript, "non-ASCII character");
                                  }
                                  return yytext[0];
                              }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 425 "sieve/sieve-lex.l"
ECHO;
	YY_BREAK
#line 2582 "sieve/sieve-lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(QCOLLATION):
case YY_STATE_EOF(QRELATION):
case YY_STATE_EOF(QIMPORTANCE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 917 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 917 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 916);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
	if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 425 "sieve/sieve-lex.l"


/* convert numerical string w/units to unsigned long */
static unsigned long long tonum(const char *str)
{
    char *units;
    unsigned long long val = strtoull(str, &units, 10);

    if (*units && errno != ERANGE) {
        switch (toupper(*units)) {
        case 'K': val *= (1ULL << 10); break;
        case 'M': val *= (1ULL << 20); break;
        case 'G': val *= (1ULL << 30); break;
            /* for future use */
        case 'T': val *= (1ULL << 40); break;
        case 'P': val *= (1ULL << 50); break;
        case 'E': val *= (1ULL << 60); break;
        default: break;
        }
    }

    return val;
}

/* convert unicode to sequence of UTF-8 characters */
static size_t unicode_to_utf8(unsigned char buf[], unsigned int code)
{
    if (code <= 0x7F) {
        buf[0] = code;
        return 1;
    }
    if (code <= 0x7FF) {
        buf[0] = 0xC0 | (code >> 6);            /* 110xxxxx */
        buf[1] = 0x80 | (code & 0x3F);          /* 10xxxxxx */
        return 2;
    }
    if (code < 0xE000 && code > 0xD7FF) return 0;
    if (code <= 0xFFFF) {
        buf[0] = 0xE0 | (code >> 12);           /* 1110xxxx */
        buf[1] = 0x80 | ((code >> 6) & 0x3F);   /* 10xxxxxx */
        buf[2] = 0x80 | (code & 0x3F);          /* 10xxxxxx */
        return 3;
    }
    if (code <= 0x10FFFF) {
        buf[0] = 0xF0 | (code >> 18);           /* 11110xxx */
        buf[1] = 0x80 | ((code >> 12) & 0x3F);  /* 10xxxxxx */
        buf[2] = 0x80 | ((code >> 6) & 0x3F);   /* 10xxxxxx */
        buf[3] = 0x80 | (code & 0x3F);          /* 10xxxxxx */
        return 4;
    }
    return 0;
}

/*
  Decode "encoded-character" strings having one of the following two forms:

  encoded-arb-octets   =  "${hex:" hex-pair-seq "}"
  hex-pair-seq         =  *blank hex-pair *(1*blank hex-pair) *blank
  hex-pair             =  1*2HEXDIG

  encoded-unicode-char =  "${unicode:" unicode-hex-seq "}"
  unicode-hex-seq      =  *blank unicode-hex *(1*blank unicode-hex) *blank
  unicode-hex          =  1*HEXDIG
   
  blank                =  WSP / CRLF
  WSP                  =  SP / HTAB 
  HEXDIG               =  DIGIT / "A" / "B" / "C" / "D" / "E" / "F"
*/
static int decode_string(struct buf *buf)
{
    static struct buf decode_buf = BUF_INITIALIZER;
    const char *cp, *enc_start;

    for (cp = buf_cstring(buf); (enc_start = strstr(cp, "${")); ) {
        unsigned is_unicode = 0;
        size_t len;

        cp = enc_start + 2;

        if (!strncasecmp(cp, "hex:", 4)) {
            cp += 4;
        }
        else if (!strncasecmp(cp, "unicode:", 8)) {
            is_unicode = 1;
            cp += 8;
        }
        else {
            /* not coded */
            continue;
        }

        /* eat leading whitespace */
        while (isspace(*cp)) cp++;

        /* sanity check "encoded" data (being liberal in accepting 'a' - 'f') */
        len = strspn(cp, "0123456789ABCDEFabcdef \t\r\n");
        if (!isxdigit(*cp) || cp[len] != '}') continue;

        /* decode characters */
        buf_reset(&decode_buf);
        do {
            unsigned int ndigits, code;

            for (ndigits = 0, code = 0; isxdigit(*cp); ndigits++, cp++) {
                unsigned int digit = 
                    (*cp > '9') ? 10 + toupper(*cp) - 'A' : *cp - '0';

                code = (code << 4) + digit;
            }

            if (is_unicode) {
                unsigned char utf8[4];

                len = unicode_to_utf8(utf8, code);
                if (!len) {
                    /* invalid UTF-8 encoding - error */
                    return 0;
                }

                /* append decoded unicode char(s) to buffer */
                buf_appendmap(&decode_buf, (char *) utf8, len);
            }
            else if (ndigits > 2) {
                /* too many hex digits - treat as not coded */
                buf_reset(&decode_buf);
                cp += len + 1;
                break;
            }
            else {
                /* append decoded hex char to buffer */
                buf_putc(&decode_buf, code);
            }

            /* eat trailing whitespace */
            while (isspace(*cp)) cp++;

        } while (*cp != '}');

        if ((len = buf_len(&decode_buf))) {
            /* replace the encoded string with its decoded value */
            size_t offset = enc_start - buf_base(buf);

            buf_remove(buf, offset, cp - enc_start + 1);
            buf_insert(buf, offset, &decode_buf);

            /* buffer may have been reallocated - reposition our pointer */
            cp = buf_cstring(buf) + offset + len;
        }
    }

    return 1;
}

